[llvm-commits] CVS: llvm/include/llvm/Transforms/Scalar.h
Chris Lattner
lattner at cs.uiuc.edu
Mon May 1 21:24:33 PDT 2006
Changes in directory llvm/include/llvm/Transforms:
Scalar.h updated: 1.63 -> 1.64
---
Log message:
Add pass ID's for various passes, so they can be AddRequiredID. Patch by
Domagoj Babic!
---
Diffs of the changes: (+20 -14)
Scalar.h | 34 ++++++++++++++++++++--------------
1 files changed, 20 insertions(+), 14 deletions(-)
Index: llvm/include/llvm/Transforms/Scalar.h
diff -u llvm/include/llvm/Transforms/Scalar.h:1.63 llvm/include/llvm/Transforms/Scalar.h:1.64
--- llvm/include/llvm/Transforms/Scalar.h:1.63 Thu Apr 20 10:45:54 2006
+++ llvm/include/llvm/Transforms/Scalar.h Mon May 1 23:24:20 2006
@@ -163,6 +163,7 @@
// ret int %Y
//
FunctionPass *createPromoteMemoryToRegisterPass();
+extern const PassInfo *PromoteMemoryToRegisterID;
//===----------------------------------------------------------------------===//
//
@@ -240,31 +241,36 @@
extern const PassInfo *LoopSimplifyID;
//===----------------------------------------------------------------------===//
+// This pass converts SelectInst instructions into conditional branch and PHI
+// instructions. If the OnlyFP flag is set to true, then only floating point
+// select instructions are lowered.
//
-// This pass eliminates call instructions to the current function which occur
-// immediately before return instructions.
-//
-FunctionPass *createTailCallEliminationPass();
-
+FunctionPass *createLowerSelectPass(bool OnlyFP = false);
+extern const PassInfo *LowerSelectID;
//===----------------------------------------------------------------------===//
// This pass convert malloc and free instructions to %malloc & %free function
// calls.
//
FunctionPass *createLowerAllocationsPass(bool LowerMallocArgToInteger = false);
+extern const PassInfo *LowerAllocationsID;
//===----------------------------------------------------------------------===//
-// This pass converts SwitchInst instructions into a sequence of chained binary
-// branch instructions.
//
-FunctionPass *createLowerSwitchPass();
+// This pass eliminates call instructions to the current function which occur
+// immediately before return instructions.
+//
+FunctionPass *createTailCallEliminationPass();
//===----------------------------------------------------------------------===//
-// This pass converts SelectInst instructions into conditional branch and PHI
-// instructions. If the OnlyFP flag is set to true, then only floating point
-// select instructions are lowered.
+// This pass converts SwitchInst instructions into a sequence of chained binary
+// branch instructions.
//
-FunctionPass *createLowerSelectPass(bool OnlyFP = false);
+FunctionPass *createLowerSwitchPass();
+extern const PassInfo *LowerSwitchID;
//===----------------------------------------------------------------------===//
// This pass converts PackedType operations into low-level scalar operations.
More information about the llvm-commits
@@ -240,31 +241,36 @@
//===----------------------------------------------------------------------===//
-// This pass convert malloc and free instructions to %malloc & %free function
-// calls.
+//
+// LowerAllocations Pass - Turn malloc and free instructions into %malloc and
+// %free calls.
+//
+// AU.addRequiredID(LowerAllocationsID);
//
FunctionPass *createLowerAllocationsPass(bool LowerMallocArgToInteger = false);
mailing list